@@ -24,7 +24,7 @@
 
 
 __project__ = "pigit"
-__version__ = "1.3.3"
+__version__ = "1.3.4"
 __url__ = "https://github.com/zlj-zz/pigit.git"
 __uri__ = __url__
 
@@ -55,9 +55,15 @@ from .config import Config
 from .codecounter import CodeCounter
 from .gitignore import GitignoreGenetor
 from .shellcompletion import shell_compele, process_argparse
-from .interaction import InteractiveStatus, InteractiveCommit
 from .processor import CmdProcessor, Git_Cmds, CommandType
 
+if not sys.platform.lower().startswith("win"):
+    from .interaction import main as interactive_interface
+else:
+
+    def interactive_interface(args=None):
+        print(render_str("`Windows not support this.`<#FF0000>"))
+
 
 Log = logging.getLogger(__name__)
 
@@ -102,7 +108,7 @@ def introduce() -> None:
 
     # Print version.
     print(
-        """
+        """\
  ____ ___ ____ ___ _____
 |  _ \\_ _/ ___|_ _|_   _|
 | |_) | | |  _ | |  | |
@@ -269,32 +275,6 @@ def shell_mode(git_processor: CmdProcessor):
     return None
 
 
-def interactive_interface(args):
-    cache_flag: int = 1  # prevent range out, caches the last selection.
-    flag: int = 1
-
-    if args:
-        ready_flag = args[0]
-        if ready_flag in "0123456789":
-            flag = int(ready_flag)
-
-    while flag and flag > 0:
-        if flag == 1:
-            cache_flag = flag
-            flag = InteractiveStatus(
-                use_color=CONFIG.gitprocessor_interactive_color,
-                help_wait=CONFIG.gitprocessor_interactive_help_showtime,
-            ).run()
-        elif flag == 2:
-            cache_flag = flag
-            flag = InteractiveCommit(
-                use_color=CONFIG.gitprocessor_interactive_color,
-                help_wait=CONFIG.gitprocessor_interactive_help_showtime,
-            ).run()
-        else:
-            flag = cache_flag
-
-
 class CustomHelpFormatter(argparse.HelpFormatter):
     """Formatter for generating usage messages and argument help strings.
 
