@@ -6,7 +6,7 @@ import logging
 from typing import Optional
 from urllib.request import urlopen
 
-from .common import Fx, Emotion, confirm
+from .common import Fx, Emoji, confirm
 
 Log = logging.getLogger(__name__)
 
@@ -15,7 +15,7 @@ class GitignoreGenetor(object):
     """Generate gitignore template.
 
     Attributes:
-        Genres (dict): supported type.
+        Supported_Types (dict): supported type.
 
     Raises:
         SystemExit: Can't get template.
@@ -48,7 +48,7 @@ class GitignoreGenetor(object):
         "unity": "Unity",
     }
 
-    def __init__(self, timeout=60) -> None:
+    def __init__(self, timeout: int = 60) -> None:
         super(GitignoreGenetor, self).__init__()
 
         self.timeout = timeout
@@ -144,9 +144,10 @@ class GitignoreGenetor(object):
                     fd.write(ignore_content)
             except Exception as e:
                 Log.error(str(e) + str(e.__traceback__))
-                print("Write gitignore file failed.")
-                print("You can copy it with the following:")
+                print(
+                    "Write gitignore file failed. You can copy it with the following:"
+                )
                 print("#" * 60)
                 print(ignore_content)
             else:
-                print("Write gitignore file successful. {0}".format(Emotion.smiler))
+                print("Write gitignore file successful. {0}".format(Emoji.smiler))
